#!/usr/bin/perl -w

=head1 NAME

B<POWER::LOG> -  

=head1 SYNOPSIS

 use POWER::LOG;

 $DEBUG = POWER::LOG->new(\*STDERR);
 $DEBUG->prefix("%D %T %P::%F() : ");
 $DEBUG->loglevel($loglevel);
 $DEBUG->log($message);
 $DEBUG->log($message, $loglevel);

=head1 DESCRIPTION

      .
       .
     loglevel   
.

=head1 METHODS

=over 4

=cut

package POWER::LOG;

use strict;
use vars qw($VERSION);

$VERSION = "1.01";

=item B<new>( \*FILE, [$prefix], [$loglevel] )

         FILE.
FILE       .
 $prefix  $loglevel    prefix()  loglevel().

     ( $DEBUG2 = $DEBUG->new() ) 
FILE, prefix  loglevel  ,     .

=cut

sub new {
    my $self  = shift;
    my $class = ref($self) || $self ;
    my $this  = ref($self) ? { %$self } : { };
	$this->{FILE} = shift;
    bless $this, $class ;
	$this->prefix(shift);
	$this->loglevel(shift);
	return $this;
}

=item B<prefix>( [$prefix] )

 ,       
.  $prefix     ,   
   .     printf(),  
,     :

 %D -    :  "//"
 %T -    : "::"
 %P -   : "main"  "POWER::NB::IO"
 %F -   :   "my_func_name"
 %% -  "%"

 : "%D %T %P::%F() "

  .

=cut

sub prefix {
	my $this = shift;
	$this->{PREFIX} = shift if @_;
	return $this->{PREFIX};
}

=item B<loglevel>( [$loglevel] )

 $loglevel     1,   
 .  $loglevel  1      
,   loglevel    $loglevel.

  loglevel.

=cut

sub loglevel {
	my $this = shift;
	$this->{LOGLEVEL} = shift if @_;
	return $this->{LOGLEVEL};
}

=item B<log>( $message[, $loglevel] )

   $loglevel    ,   
 loglevel().  $loglevel  ,    1.
.  prefix().

=cut

sub log {
	my ($this, $msg, $loglevel) = @_;
	$loglevel ||= 1;
	return if $this->loglevel() < 1 or $loglevel > $this->loglevel();
	my $date = sub {sprintf "%02d/%02d/%04d", $_[3], $_[4]+1, $_[5]+1900}->(localtime);
	my $time = sub {sprintf "%02d:%02d:%02d", $_[2], $_[1], $_[0]}->(localtime);
	my ($pkg, $func) = (caller(1))[3] =~ /^(.*)::(.*)$/;
	my %data = ("%"=>"%", "D"=>$date, "T"=>$time, "P"=>$pkg, "F"=>$func);
	(my $prefix = $this->prefix()) =~ s/%(.)/$data{$1}/g;
	$msg =~ s/^/$prefix/mg;
	$msg =~ s/\n?$/\n/;
	my $FILE = $this->{FILE};
	print $FILE $msg;
}

=back

=head1 HISTORY

 1.01         28 21:28:52 EET 2001
      -   /
 1.00		  28 16:48:16 EET 2001
      -     ( print)

=head1 AUTHOR

Alex Efros <powerman@consultant.com>

=cut

